Package 'kwb.svn'

Title: Functions for Subversion
Description: Helper Functions for analysing Subversion log information.
Authors: Michael Rustler [aut, cre] (ORCID: <https://orcid.org/0000-0003-0647-7726>), Hauke Sonnenberg [aut] (ORCID: <https://orcid.org/0000-0001-9134-2871>), FAKIN [fnd], Kompetenzzentrum Wasser Berlin gGmbH (KWB) [cph]
Maintainer: Michael Rustler <[email protected]>
License: MIT + file LICENSE
Version: 0.1.0
Built: 2026-06-01 07:49:16 UTC
Source: https://github.com/KWB-R/kwb.svn

Help Index


Default SVN Repository

Description

Default SVN Repository

Usage

default_repo(
  serverip = Sys.getenv("SVN_IP"),
  username = Sys.getenv("SVN_USER"),
  password = Sys.getenv("SVN_PW"),
  root_dir = "svn/kwb"
)

Arguments

serverip

serverip for repo (default: Sys.getenv("SVN_IP") )

username

username for repo (default: Sys.getenv("SVN_USER"))

password

password for repo (default: Sys.getenv("SVN_PW"))

root_dir

root directory (default: "svn/kwb")

Value

string to svn repo with login


Default SVN Repository RScripts

Description

Default SVN Repository RScripts

Usage

default_rscripts()

Title

Description

Title

Usage

extractCommit(commit)

Arguments

commit

commit number

Value

data frame with commit information


Get Commit Infos

Description

Get Commit Infos

Usage

extractCommitInfo(commits)

Arguments

commits

commits

Value

commit infos


Extract Entry Name and Commit

Description

Extract Entry Name and Commit

Usage

extractEntryNameAndCommit(entryName, entryCommit)

Arguments

entryName

entryName

entryCommit

entryCommit

Value

data.frame with name, author and data


Default SVN Repository RScripts Paths

Description

Default SVN Repository RScripts Paths

Usage

get_rscript_paths(rscripts_path = default_rscripts())

Arguments

rscripts_path

default R scripts path default: default_rscripts


Get Repo Info

Description

Get Repo Info

Usage

getRepoInfo(
  currentRevision = 1920,
  startRevision = 2,
  tDir = tempdir(),
  repo = default_repo(),
  logs = TRUE,
  dbg = TRUE
)

Arguments

currentRevision

latest SVN revision

startRevision

start SVN revision

tDir

target directory (default: tempdir())

repo

repository (default: default_repo())

logs

if TRUE logs info is extracted, if FALSE size info (default: TRUE)

dbg

debug messages (default: TRUE)

Value

writes files with repo log info into target directory and returns path to target directory


Get Revision Information

Description

Get Revision Information

Usage

getRevisionInfo(
  revision,
  tDir = tempdir(),
  repo = default_repo(),
  logs = TRUE,
  fPrefix = "ente",
  dbg = TRUE
)

Arguments

revision

revision number

tDir

target directory

repo

repository

logs

if TRUE logs info is extracted, if FALSE size info (default: TRUE)

fPrefix

file prefix (default: "ente")

dbg

debug messages (default: TRUE)

Value

revision infos


Read SVN History For Files

Description

Read SVN History For Files

Usage

read_files_history(repo = default_rscripts(), tdir = tempdir(), dbg = TRUE)

Arguments

repo

path to repository (default: default_repo())

tdir

target directory (default: tempdir())

dbg

debug (default: TRUE)

Value

writes history files to target directory and returns target directory


Read Histories

Description

Read Histories

Usage

read_histories(history_dir)

Arguments

history_dir

directory with history files (as created with

Value

data.frame with columns


Read Logfile

Description

Read Logfile

Usage

readLogFile(logfile)

Arguments

logfile

logfile

Value

logfile


Read SVN Logfiles In A Directory

Description

Read SVN Logfiles In A Directory

Usage

readLogFilesInDirectory(logdir, pattern = "_log_")

Arguments

logdir

directory containing svn log information

pattern

pattern (default: "_log_")

Value

data frame with svn log data


Read Size Files

Description

Read Size Files

Usage

readSizeFiles(fDir, fPattern = "ente_r", dbg = FALSE)

Arguments

fDir

directory containing data with file size information

fPattern

file pattern (default: "ente_r")

dbg

debug (default: FALSE)

Value

list with size file information