| Title: | Functions for Subversion |
|---|---|
| Description: | Helper Functions for analysing Subversion log information. |
| Authors: | Michael Rustler [aut, cre] (ORCID: <https://orcid.org/0000-0003-0647-7726>), Hauke Sonnenberg [aut] (ORCID: <https://orcid.org/0000-0001-9134-2871>), FAKIN [fnd], Kompetenzzentrum Wasser Berlin gGmbH (KWB) [cph] |
| Maintainer: | Michael Rustler <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-06-01 07:49:16 UTC |
| Source: | https://github.com/KWB-R/kwb.svn |
Default SVN Repository
default_repo( serverip = Sys.getenv("SVN_IP"), username = Sys.getenv("SVN_USER"), password = Sys.getenv("SVN_PW"), root_dir = "svn/kwb" )default_repo( serverip = Sys.getenv("SVN_IP"), username = Sys.getenv("SVN_USER"), password = Sys.getenv("SVN_PW"), root_dir = "svn/kwb" )
serverip |
serverip for repo (default: Sys.getenv("SVN_IP") ) |
username |
username for repo (default: Sys.getenv("SVN_USER")) |
password |
password for repo (default: Sys.getenv("SVN_PW")) |
root_dir |
root directory (default: "svn/kwb") |
string to svn repo with login
Default SVN Repository RScripts
default_rscripts()default_rscripts()
Title
extractCommit(commit)extractCommit(commit)
commit |
commit number |
data frame with commit information
Get Commit Infos
extractCommitInfo(commits)extractCommitInfo(commits)
commits |
commits |
commit infos
Extract Entry Name and Commit
extractEntryNameAndCommit(entryName, entryCommit)extractEntryNameAndCommit(entryName, entryCommit)
entryName |
entryName |
entryCommit |
entryCommit |
data.frame with name, author and data
Default SVN Repository RScripts Paths
get_rscript_paths(rscripts_path = default_rscripts())get_rscript_paths(rscripts_path = default_rscripts())
rscripts_path |
default R scripts path default: |
Get Repo Info
getRepoInfo( currentRevision = 1920, startRevision = 2, tDir = tempdir(), repo = default_repo(), logs = TRUE, dbg = TRUE )getRepoInfo( currentRevision = 1920, startRevision = 2, tDir = tempdir(), repo = default_repo(), logs = TRUE, dbg = TRUE )
currentRevision |
latest SVN revision |
startRevision |
start SVN revision |
tDir |
target directory (default: tempdir()) |
repo |
repository (default: default_repo()) |
logs |
if TRUE logs info is extracted, if FALSE size info (default: TRUE) |
dbg |
debug messages (default: TRUE) |
writes files with repo log info into target directory and returns path to target directory
Get Revision Information
getRevisionInfo( revision, tDir = tempdir(), repo = default_repo(), logs = TRUE, fPrefix = "ente", dbg = TRUE )getRevisionInfo( revision, tDir = tempdir(), repo = default_repo(), logs = TRUE, fPrefix = "ente", dbg = TRUE )
revision |
revision number |
tDir |
target directory |
repo |
repository |
logs |
if TRUE logs info is extracted, if FALSE size info (default: TRUE) |
fPrefix |
file prefix (default: "ente") |
dbg |
debug messages (default: TRUE) |
revision infos
Read SVN History For Files
read_files_history(repo = default_rscripts(), tdir = tempdir(), dbg = TRUE)read_files_history(repo = default_rscripts(), tdir = tempdir(), dbg = TRUE)
repo |
path to repository (default: default_repo()) |
tdir |
target directory (default: tempdir()) |
dbg |
debug (default: TRUE) |
writes history files to target directory and returns target directory
Read Histories
read_histories(history_dir)read_histories(history_dir)
history_dir |
directory with history files (as created with |
data.frame with columns
Read Logfile
readLogFile(logfile)readLogFile(logfile)
logfile |
logfile |
logfile
Read SVN Logfiles In A Directory
readLogFilesInDirectory(logdir, pattern = "_log_")readLogFilesInDirectory(logdir, pattern = "_log_")
logdir |
directory containing svn log information |
pattern |
pattern (default: "_log_") |
data frame with svn log data
Read Size Files
readSizeFiles(fDir, fPattern = "ente_r", dbg = FALSE)readSizeFiles(fDir, fPattern = "ente_r", dbg = FALSE)
fDir |
directory containing data with file size information |
fPattern |
file pattern (default: "ente_r") |
dbg |
debug (default: FALSE) |
list with size file information